#
# spec file for package slop
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
Name:           slop
%define lname	libslopy7_6
Version:        7.6
Release:        bp156.2.7
Summary:        Tool to query for a screen region selection
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/naelstrof/slop
Source0:        https://github.com/naelstrof/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gengetopt
BuildRequires:  glm-devel
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(xrandr)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
slop (Select Operation) queries for a selection from the user and prints
the region to stdout. It grabs the mouse and turns it into a crosshair,
lets the user click and drag to make a selection (or click on a window)
while drawing a pretty box around it, then finally prints the selection's
dimensions to stdout.

%package -n %{lname}
Summary:        Screen region selection library
Group:          System/Libraries
# slop 7.6 wrongly called this package libslopy7_5
Conflicts:      libslopy7_5 = 7.6

%description -n %{lname}
This library implements the slop utility's functionality to mark a
region ont the screen.

%package devel
Summary:        Development files for the slop library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Header files for the slop library.

%prep
%setup -q

%build
%cmake
make %{?_smp_mflags}

%install
pushd build/
%make_install
popd

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/*.1*

%files -n %{lname}
%{_libdir}/libslopy.so.7*

%files devel
%{_includedir}/*
%{_libdir}/libslopy.so

%changelog
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Rename libslopy7_5 subpackage to libslopy7_6 to actually match
  the soname of the library. Conflict wit the previously wrong
  packaged version.
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 7.6:
  fixed missing images, version bump for previous merges
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 7.5:
  * Added --nodrag option
  * Selections can be moved by holding the space-bar mid-drag!
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 7.4 [boo#1113605]
  * Slop now no longer selects shadows around windows in Mutter.
    Gone is the annoying arbitrary padding around Gnome windows.
  * Users can now supply their own shaders to create neat effects.
    Slop allows for chained post-processing shaders. Shaders are
    written in a language called GLSL.
  * Slop uses EGL now (allowing for fancy rectangles while pulling
    the mouse to make a region), and falls back to XShape
    otherwise.
* Thu Sep  3 2015 nemysis@openSUSE.org
- Update to 4.2.19, announce message is here:
    https://github.com/naelstrof/slop/releases/tag/v4.2.19
* Sun Jul 12 2015 nemysis@gmx.ch
- Update to 4.2.18, announce message is here:
    https://github.com/naelstrof/slop/releases
* Sun Jul 12 2015 nemysis@gmx.ch
- Update to 4.2.17, announce message is here:
    https://github.com/naelstrof/slop/releases/tag/v4.2.17
- Remove BuildRequires for pkgconfig(xext)
- Add BuildRequires for glm-devel, pkgconfig(gl), pkgconfig(glew),
  pkgconfig(glu), pkgconfig(imlib2) and pkgconfig(xrandr)
* Sat Jun 27 2015 nemysis@gmx.ch
- Remove v3.1.5.tar.gz, forgotten in previous commit
* Fri Jun 26 2015 nemysis@gmx.ch
- Update to 4.1.16, announce message:
  Added opacity capabilities. --color now checks for an alpha value,
  but it's optional.
  Added new option --highlight. Which instead of drawing a border around
  the selection, it draws over the selection. Best used with --color
  with an alpha set below 1.
  Added option --minimumsize and --maximumsize, setting them both to
  the same value disables drag selections.
  Slop windows now let all events fall through.
  Incredibly improved rendering quality and speed, no longer do I
  re-size or move windows around. For some reason that's really
    expensive in X11...
  Slop now outputs the ID of a selected window if any.
  Minor bugfixes and adjustments.
- Change Source0 Web URL, to have right slop-4.1.16.tar.gz
- Add BuildRequires for cmake and gengetopt
- Add BuildRoot
- Use %%{name} instead of maim
- Add Documentation
- Add %%changelog
* Mon Oct 20 2014 rneuhauser@suse.cz
- slop-3.1.5
* Fri Oct 17 2014 rneuhauser@suse.cz
- slop-3.1.4
